tests.test_print module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »

# tests.test_print module

## tests.test_print

Tests string representation of graph.

class `tests.test_print.` `TestGraphPrint`

  Bases: `object`

  Test aspects of string representation of graphs.

  `test_num_string`()

    Verify that the number of strings is at least a node’s out-degree.

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »